referees.display

# XMLRésuméLibrary: User Guide

interest.description.format | XSL Parameter Reference | skills.format

## Name

referees.display — Determines whether or not referees are visible in formatted output

## Applies To

This parameter controls the formatting of the `referee` element in all output formats.

## Possible Values

Possible values include `1` (display referees) and `0` (display alternate text).

`1` (true)

  Referees are displayed in formatted output.

`0` (false)

  The text of the `referees.hidden.phrase` parameter (default: `Available upon request.`) is displayed in place of referees.

interest.description.format | XSL Parameter Reference | skills.format